==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm2015/lib/ScatterSplineSeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ScatterBase } from "./ScatterBase";
import { DependencyProperty } from "igniteui-angular-core";
import { Point_$type, typeCast, runOn, markType, markDep } from "igniteui-angular-core";
import { ScatterFrame } from "./ScatterFrame";
import { ScatterSplineSeriesView } from "./ScatterSplineSeriesView";
import { Defaults } from "./Defaults";
import { Clipper } from "igniteui-angular-core";
import { ScalerParams } from "./ScalerParams";
import { OwnedPoint } from "./OwnedPoint";
import { PathGeometry } from "igniteui-angular-core";
import { Numeric } from "igniteui-angular-core";
import { PropertyMetadata } from "igniteui-angular-core";
import { isNaN_ } from "igniteui-angular-core";
/**
 * @hidden
 */
export let ScatterSplineSeries = /*@__PURE__*/ (() => {
    class ScatterSplineSeries extends ScatterBase {
        constructor() {
            super();
            this.ab = ScatterSplineSeries.$;
            this.sb = new ScatterFrame();
            this.sd = new ScatterFrame();
            this.r9 = new ScatterFrame();
        }
        get_ej() {
            return true;
        }
        by() {
            return new ScatterSplineSeriesView(this);
        }
        gz() {
            if (!isNaN_(this.gy)) {
                return super.gz();
            }
            return Defaults.x;
        }
        l9(a, b, c, d) {
            super.l9(a, b, c, d);
            switch (b) {
                case ScatterSplineSeries.$$p[0]:
                    this.mn(false);
                    this.lu();
                    break;
            }
        }
        bq() {
            if (this.br == 0) {
                return 2;
            }
            else {
                return super.bq();
            }
        }
        ua(a, b) {
            super.ua(a, b);
            a.m.clear();
            a.u.clear();
            let c = b.bv;
            let d = b.bu;
            let e = this.getEffectiveViewport1(b);
            let f = this.fx * this.fx;
            let g = Math.min(this.sl != null ? this.sl.count : 0, this.sm != null ? this.sm.count : 0);
            let h = new ScalerParams(0, c, d, this.r5.d, e);
            let i = ((() => {
                let $ret = new ScalerParams(0, c, d, this.r5.e, e);
                $ret.b = this.gg();
                return $ret;
            })());
            let j = (k) => this.r5.a.ei(this.sl.item(k), h);
            let k = (l) => this.r5.b.ei(this.sm.item(l), i);
            let l = ((() => {
                let $ret = new Clipper(0, d, false);
                $ret.i = a.m;
                return $ret;
            })());
            for (let m = 0; m < g;) {
                let n = m;
                ++m;
                while (m < g && this.vg(j, k, n, m) < f) {
                    ++m;
                }
                if (g > this.tb) {
                    l.j(this.vk(j, k, n, m - 1));
                }
                else {
                    let o = new OwnedPoint();
                    o.c = { $type: Point_$type, x: j(n), y: k(n) };
                    o.a = this.cl.item(n);
                    if (!a.u.containsKey(o.a)) {
                        a.u.addItem(o.a, o);
                    }
                }
            }
            if (g > this.tb) {
                l.i = null;
            }
        }
        vk(a, b, c, d) {
            if (c == d) {
                return { $type: Point_$type, x: a(c), y: b(c) };
            }
            let e = 0;
            let f = 0;
            let g = (d - c + 1);
            for (let h = c; h <= d; ++h) {
                e += a(h);
                f += b(h);
            }
            return { $type: Point_$type, x: e / g, y: f / g };
        }
        vg(a, b, c, d) {
            let e = a(d) - a(c);
            let f = b(d) - b(c);
            return e * e + f * f;
        }
        get_su() {
            return true;
        }
        k2(a, b) {
            super.k2(a, b);
            let c = typeCast(ScatterSplineSeriesView.$, b);
            c.c4(false);
        }
        ul(a, b) {
            this.k2(false, b);
            super.ul(a, b);
            this.ud(a);
            let c = typeCast(ScatterSplineSeriesView.$, b);
            let d = c.dg;
            this.si.az(this, this.sz(), runOn(this, this.rt));
            let e = false;
            let f = this.si.b;
            if (f != null) {
                e = true;
            }
            if (e) {
                this.t6(-1, this.sl.count, b.q);
            }
            this.si.ad(d, true, false, true, false);
            c.dg.an = new PathGeometry();
            c.dg.an.c = Numeric.h(a.m.count, (g) => a.m._inner[g].x, (g) => a.m._inner[g].y, this.vh);
        }
    }
    ScatterSplineSeries.$t = markType(ScatterSplineSeries, 'ScatterSplineSeries', ScatterBase.$);
    ScatterSplineSeries.$$p = markDep(DependencyProperty, PropertyMetadata, ScatterSplineSeries, 'raisePropertyChanged', ['Stiffness:vh:vj', [1, 0.5]]);
    return ScatterSplineSeries;
})();

==> igniteui-angular-charts-17.0.0-beta.0.tgz: package/esm2015/lib/ScatterSplineSeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ScatterBase } from "./ScatterBase";
import { DependencyProperty } from "igniteui-angular-core";
import { Point_$type, typeCast, runOn, markType, markDep } from "igniteui-angular-core";
import { ScatterFrame } from "./ScatterFrame";
import { ScatterSplineSeriesView } from "./ScatterSplineSeriesView";
import { Defaults } from "./Defaults";
import { Clipper } from "igniteui-angular-core";
import { ScalerParams } from "./ScalerParams";
import { OwnedPoint } from "./OwnedPoint";
import { PathGeometry } from "igniteui-angular-core";
import { Numeric } from "igniteui-angular-core";
import { PropertyMetadata } from "igniteui-angular-core";
import { isNaN_ } from "igniteui-angular-core";
/**
 * @hidden
 */
export let ScatterSplineSeries = /*@__PURE__*/ (() => {
    class ScatterSplineSeries extends ScatterBase {
        constructor() {
            super();
            this.ab = ScatterSplineSeries.$;
            this.sb = new ScatterFrame();
            this.sd = new ScatterFrame();
            this.r9 = new ScatterFrame();
        }
        get_ej() {
            return true;
        }
        by() {
            return new ScatterSplineSeriesView(this);
        }
        gz() {
            if (!isNaN_(this.gy)) {
                return super.gz();
            }
            return Defaults.x;
        }
        l9(a, b, c, d) {
            super.l9(a, b, c, d);
            switch (b) {
                case ScatterSplineSeries.$$p[0]:
                    this.mn(false);
                    this.lu();
                    break;
            }
        }
        bq() {
            if (this.br == 0) {
                return 2;
            }
            else {
                return super.bq();
            }
        }
        ua(a, b) {
            super.ua(a, b);
            a.m.clear();
            a.u.clear();
            let c = b.bv;
            let d = b.bu;
            let e = this.getEffectiveViewport1(b);
            let f = this.fx * this.fx;
            let g = Math.min(this.sl != null ? this.sl.count : 0, this.sm != null ? this.sm.count : 0);
            let h = new ScalerParams(0, c, d, this.r5.d, e);
            let i = ((() => {
                let $ret = new ScalerParams(0, c, d, this.r5.e, e);
                $ret.b = this.gg();
                return $ret;
            })());
            let j = (k) => this.r5.a.ej(this.sl.item(k), h);
            let k = (l) => this.r5.b.ej(this.sm.item(l), i);
            let l = ((() => {
                let $ret = new Clipper(0, d, false);
                $ret.i = a.m;
                return $ret;
            })());
            for (let m = 0; m < g;) {
                let n = m;
                ++m;
                while (m < g && this.vg(j, k, n, m) < f) {
                    ++m;
                }
                if (g > this.tb) {
                    l.j(this.vk(j, k, n, m - 1));
                }
                else {
                    let o = new OwnedPoint();
                    o.c = { $type: Point_$type, x: j(n), y: k(n) };
                    o.a = this.cl.item(n);
                    if (!a.u.containsKey(o.a)) {
                        a.u.addItem(o.a, o);
                    }
                }
            }
            if (g > this.tb) {
                l.i = null;
            }
        }
        vk(a, b, c, d) {
            if (c == d) {
                return { $type: Point_$type, x: a(c), y: b(c) };
            }
            let e = 0;
            let f = 0;
            let g = (d - c + 1);
            for (let h = c; h <= d; ++h) {
                e += a(h);
                f += b(h);
            }
            return { $type: Point_$type, x: e / g, y: f / g };
        }
        vg(a, b, c, d) {
            let e = a(d) - a(c);
            let f = b(d) - b(c);
            return e * e + f * f;
        }
        get_su() {
            return true;
        }
        k2(a, b) {
            super.k2(a, b);
            let c = typeCast(ScatterSplineSeriesView.$, b);
            c.c4(false);
        }
        ul(a, b) {
            this.k2(false, b);
            super.ul(a, b);
            this.ud(a);
            let c = typeCast(ScatterSplineSeriesView.$, b);
            let d = c.dg;
            this.si.az(this, this.sz(), runOn(this, this.rt));
            let e = false;
            let f = this.si.b;
            if (f != null) {
                e = true;
            }
            if (e) {
                this.t6(-1, this.sl.count, b.q);
            }
            this.si.ad(d, true, false, true, false);
            c.dg.an = new PathGeometry();
            c.dg.an.c = Numeric.h(a.m.count, (g) => a.m._inner[g].x, (g) => a.m._inner[g].y, this.vh);
        }
    }
    ScatterSplineSeries.$t = markType(ScatterSplineSeries, 'ScatterSplineSeries', ScatterBase.$);
    ScatterSplineSeries.$$p = markDep(DependencyProperty, PropertyMetadata, ScatterSplineSeries, 'raisePropertyChanged', ['Stiffness:vh:vj', [1, 0.5]]);
    return ScatterSplineSeries;
})();
